@@ -2,6 +2,8 @@ from weakref import WeakSet
 import numpy as np
 import colorlog
 from .utils import classproperty, get_obj_by_id
+
+from .ParameterStructure.Instances import InstanceType
 # from copy import deepcopy
 # from functools import lru_cache
 from tqdm import tqdm
@@ -234,6 +236,7 @@ class BaseGeoBaseClass(object):
         return instance
 
     def __init__(self, *args, **kwargs):
+        self.geometry_model = kwargs.get('geometry_model', None)
         self._wrapped_obj = kwargs.get('wrapped_obj', None)
 
     # @lru_cache(maxsize=None)
@@ -340,6 +343,23 @@ class BaseGeometricFace(BaseGeoBaseClass):
     def __repr__(self):
         return f'Face {self.id}: {self.name}'
 
+    @property
+    def components(self):
+        return self.geometry_model.get_geo_components(self._wrapped_obj)
+
+    @property
+    def construction_assignment(self):
+        return next((x for x in self.components if x.InstanceType == InstanceType.ALIGNED_WITH), None)
+
+    @property
+    def construction(self):
+        if self.construction_assignment is None:
+            return
+
+        component = self.construction_assignment.ReferencedComponents.Items[0].Reference
+        return self.geometry_model.template_parser.create_python_object(component, template_name='BuildInConstruction')
+
+
 
 class BaseGeometricVolume(BaseGeoBaseClass):
 
@@ -420,8 +440,3 @@ class BuildInGeoTypes(object):
 
 
 geometry_types = BuildInGeoTypes()
-
-
-
-
-
